==> index.php?action=downloadfile&directory=Tools+and+Editors%2FDreambox%2FSkin&filename=enigma2-skin-hdglass16_9.31_all.deb.zip: usr/lib/enigma2/python/Components/Renderer/g16RefTV3.py <==
#######################################################################
#
#    Converter for Enigma2
#    Coded by shamann (c)2015
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 2
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#######################################################################

from Renderer import Renderer
from enigma import ePixmap
from Tools.Directories import fileExists, SCOPE_SKIN_IMAGE, SCOPE_CURRENT_SKIN, resolveFilename
from enigma import eServiceReference, eServiceCenter
from Components.config import config

class g16RefTV3(Renderer):

	def __init__(self):
		Renderer.__init__(self)
		self.pngname = ""

	GUI_WIDGET = ePixmap

	def changed(self, what):
		if self.instance:
			pngname = ""
			if what[0] != self.CHANGED_CLEAR:
				service = self.source.service
				marker = (service.flags & eServiceReference.isMarker == eServiceReference.isMarker)
				bouquet = (service.flags & eServiceReference.flagDirectory == eServiceReference.flagDirectory)
				if not marker and not bouquet:
					sname = service.toString()
					if sname is not None and sname != "":
						tmp = self.alternative(sname).split(':', 10)[:10]
						if len(tmp) > 0 and tmp[0] == '4097':
							tmp[0] = '1'
						sname = '_'.join(tmp)
						pngname = self.findPicon(sname)
				if pngname == "":
					pngname = self.findPicon("picon_default")
					if pngname == "":
						tmp = resolveFilename(SCOPE_CURRENT_SKIN, "picon_default.png")
						if fileExists(tmp):
							pngname = tmp
						else:
							pngname = resolveFilename(SCOPE_SKIN_IMAGE, "skin_default/picon_default.png")
				if self.pngname != pngname:
					self.pngname = pngname
					self.instance.setPixmapFromFile(self.pngname)
            		
	def alternative(self, serviceName):
		def alternativeChannels(service):
			tmp = eServiceCenter.getInstance().list(eServiceReference(service))
			return tmp and tmp.getContent("S", True)
		if serviceName.startswith('1:134:'):
			channels = alternativeChannels(serviceName)
			if channels:
				return channels[0]
		return serviceName

	def findPicon(self, serviceName):
		for x in ["picon-t","ZZPicon"]:
			try:
				pngname = config.plugins.setupGlass16.par39.value + "/"+x+"/" + serviceName + ".png"
				if fileExists(pngname):
					return pngname
			except: pass
		return ""

==> index.php?action=downloadfile&directory=Tools+and+Editors%2FDreambox%2FSkin&filename=enigma2-skin-hdglass16_10.17_all.deb.zip: usr/lib/enigma2/python/Components/Renderer/g16RefTV3.py <==
#######################################################################
#
#    Converter for Enigma2
#    Coded by shamann (c)2015
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 2
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#######################################################################

from Renderer import Renderer
from enigma import ePixmap, eSize
from Tools.Directories import fileExists, SCOPE_SKIN_IMAGE, SCOPE_CURRENT_SKIN, resolveFilename
from enigma import eServiceReference, eServiceCenter
from Components.config import config

class g16RefTV3(Renderer):

	def __init__(self):
		Renderer.__init__(self)
		self.pngname = ""
		self.sizeT = 170
	GUI_WIDGET = ePixmap

	def changed(self, what):
		if self.instance:
			pngname = ""
			if what[0] != self.CHANGED_CLEAR:
				service = self.source.service
				marker = (service.flags & eServiceReference.isMarker == eServiceReference.isMarker)
				bouquet = (service.flags & eServiceReference.flagDirectory == eServiceReference.flagDirectory)
				if not marker and not bouquet:
					sname = service.toString()
					if sname is not None and sname != "":
						tmp = self.alternative(sname).split(':', 10)[:10]
						if len(tmp) > 0 and tmp[0] == '4097':
							tmp[0] = '1'
						sname = '_'.join(tmp)
						pngname = self.findPicon(sname)
				if pngname == "":
					pngname = self.findPicon("picon_default")
					if pngname == "":
						tmp = resolveFilename(SCOPE_CURRENT_SKIN, "picon_default.png")
						if fileExists(tmp):
							pngname = tmp
						else:
							pngname = resolveFilename(SCOPE_SKIN_IMAGE, "skin_default/picon_default.png")
				if self.pngname != pngname:
					self.pngname = pngname
					s = 170
					if "picon-t" in pngname:
						s = 240
					if self.sizeT != s:
						self.sizeT = s
						self.instance.resize(eSize(400,self.sizeT))
					self.instance.setPixmapFromFile(self.pngname)
            		
	def alternative(self, serviceName):
		def alternativeChannels(service):
			tmp = eServiceCenter.getInstance().list(eServiceReference(service))
			return tmp and tmp.getContent("S", True)
		if serviceName.startswith('1:134:'):
			channels = alternativeChannels(serviceName)
			if channels:
				return channels[0]
		return serviceName

	def findPicon(self, serviceName):
		for x in ["picon-t","ZZPicon"]:
			try:
				pngname = config.plugins.setupGlass16.par39.value + "/"+x+"/" + serviceName + ".png"
				if fileExists(pngname):
					return pngname
			except: pass
		return ""
